@@ -24,26 +24,35 @@
 #include <config.h>
 #include "gnome-vfs-init.h"
 
-#include "gnome-vfs-ssl-private.h"
 #include "gnome-vfs-mime.h"
 
 #include "gnome-vfs-configuration.h"
-#include "gnome-vfs-i18n.h"
 #include "gnome-vfs-method.h"
-#include "gnome-vfs-process.h"
 #include "gnome-vfs-utils.h"
+#include "gnome-vfs-private-utils.h"
 
 #include "gnome-vfs-async-job-map.h"
-#include "gnome-vfs-thread-pool.h"
 #include "gnome-vfs-job-queue.h"
+#include "gnome-vfs-volume-monitor-private.h"
+#include "gnome-vfs-module-callback-private.h"
 
 #include <errno.h>
-#include <bonobo-activation/bonobo-activation.h>
 #include <glib/gmessages.h>
 #include <glib/gfileutils.h>
-#include <libgnomevfs/gnome-vfs-job-slave.h>
+#include <glib/gi18n-lib.h>
+#include <glib/gtypes.h>
+#include <glib/gstdio.h>
+
+#ifdef USE_DAEMON
+#ifndef DBUS_API_SUBJECT_TO_CHANGE
+#define DBUS_API_SUBJECT_TO_CHANGE 1
+#endif
+#include <dbus/dbus-glib.h>
+#endif
+
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <signal.h>
 
 static gboolean vfs_already_initialized = FALSE;
 G_LOCK_DEFINE_STATIC (vfs_already_initialized);
@@ -56,16 +65,16 @@ ensure_dot_gnome_exists (void)
 	gboolean retval = TRUE;
 	gchar *dirname;
 
-	dirname = g_build_filename (g_get_home_dir (), ".gnome", NULL);
+	dirname = g_build_filename (g_get_home_dir (), ".gnome2", NULL);
 
 	if (!g_file_test (dirname, G_FILE_TEST_EXISTS)) {
-		if (mkdir (dirname, S_IRWXU) != 0) {
-			g_warning ("Unable to create ~/.gnome directory: %s",
+		if (g_mkdir (dirname, S_IRWXU) != 0) {
+			g_warning ("Unable to create ~/.gnome2 directory: %s",
 				   g_strerror (errno));
 			retval = FALSE;
 		}
 	} else if (!g_file_test (dirname, G_FILE_TEST_IS_DIR)) {
-		g_warning ("Error: ~/.gnome must be a directory.");
+		g_warning ("Error: ~/.gnome2 must be a directory.");
 		retval = FALSE;
 	}
 
@@ -74,34 +83,35 @@ ensure_dot_gnome_exists (void)
 }
 
 static void
-gnome_vfs_pthread_init (void)
+gnome_vfs_thread_init (void)
 {
 	private_is_primary_thread = g_private_new (NULL);
 	g_private_set (private_is_primary_thread, GUINT_TO_POINTER (1));
 	
-	gnome_vfs_module_callback_private_init ();
+	_gnome_vfs_module_callback_private_init ();
 	
-	gnome_vfs_async_job_map_init ();
-	gnome_vfs_thread_pool_init ();
-	gnome_vfs_job_queue_init ();
+	_gnome_vfs_async_job_map_init ();
+	_gnome_vfs_job_queue_init ();
 }
 
 /**
  * gnome_vfs_init:
  *
- * If GnomeVFS is not already initialized, initialize it. This must be
- * called prior to performing any other GnomeVFS operations, and may
+ * If gnome-vfs is not already initialized, initialize it. This must be
+ * called prior to performing any other gnome-vfs operations, and may
  * be called multiple times without error.
  * 
- * Return value: %TRUE if GnomeVFS is successfully initialized (or was
- * already initialized)
- **/
+ * Return value: %TRUE if gnome-vfs is successfully initialized (or was
+ * already initialized).
+ */
 gboolean 
 gnome_vfs_init (void)
 {
 	gboolean retval;
+	/*
 	char *bogus_argv[2] = { "dummy", NULL };
-
+	*/
+	
 	if (!ensure_dot_gnome_exists ()) {
 		return FALSE;
 	}
@@ -113,27 +123,27 @@ gnome_vfs_init (void)
 
 	if (!vfs_already_initialized) {
 #ifdef ENABLE_NLS
+		bindtextdomain (GETTEXT_PACKAGE, GNOME_VFS_LOCALEDIR);
 		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif   
-		gnome_vfs_pthread_init ();
-
-		if (bonobo_activation_orb_get() == NULL) {
-			bonobo_activation_init (0, bogus_argv);
-		}
-
-		gnome_vfs_ssl_init ();
+		gnome_vfs_thread_init ();
+#ifdef USE_DAEMON
+		dbus_g_thread_init ();
+#endif
+ 		/* Make sure the type system is inited. */
+		g_type_init ();
 
 		retval = gnome_vfs_method_init ();
 
 		if (retval) {
-			retval = gnome_vfs_process_init ();
-		}
-		if (retval) {
-			retval = gnome_vfs_configuration_init ();
+			retval = _gnome_vfs_configuration_init ();
 		}
+		
+#ifdef SIGPIPE
 		if (retval) {
 			signal (SIGPIPE, SIG_IGN);
 		}
+#endif		
 	} else {
 		retval = TRUE;	/* Who cares after all.  */
 	}
@@ -147,11 +157,11 @@ gnome_vfs_init (void)
 /**
  * gnome_vfs_initialized:
  *
- * Detects if GnomeVFS has already been initialized (GnomeVFS must be
+ * Detects if gnome-vfs has already been initialized (gnome-vfs must be
  * initialized prior to using any methods or operations).
  * 
- * Return value: %TRUE if GnomeVFS has already been initialized
- **/
+ * Return value: %TRUE if gnome-vfs has already been initialized.
+ */
 gboolean
 gnome_vfs_initialized (void)
 {
@@ -166,15 +176,18 @@ gnome_vfs_initialized (void)
 /**
  * gnome_vfs_shutdown:
  *
- * Cease all active GnomeVFS operations and unload the MIME
+ * Cease all active gnome-vfs operations and unload the MIME
  * database from memory.
  * 
- **/
+ */
 void
 gnome_vfs_shutdown (void)
 {
-	gnome_vfs_thread_backend_shutdown ();
 	gnome_vfs_mime_shutdown ();
+#ifndef G_OS_WIN32
+	_gnome_vfs_volume_monitor_shutdown ();
+#endif
+	_gnome_vfs_method_shutdown ();
 }
 
 void
@@ -192,13 +205,14 @@ gnome_vfs_postinit (gpointer app, gpointer modinfo)
 {
 	G_LOCK (vfs_already_initialized);
 
-	gnome_vfs_pthread_init ();
+	gnome_vfs_thread_init ();
 
 	gnome_vfs_method_init ();
-	gnome_vfs_process_init ();
-	gnome_vfs_configuration_init ();
+	_gnome_vfs_configuration_init ();
 
+#ifdef SIGPIPE
 	signal (SIGPIPE, SIG_IGN);
+#endif
 
 	vfs_already_initialized = TRUE;
 	G_UNLOCK (vfs_already_initialized);
@@ -210,8 +224,8 @@ gnome_vfs_postinit (gpointer app, gpointer modinfo)
  * Check if the current thread is the thread with the main glib event loop.
  *
  * Return value: %TRUE if the current thread is the thread with the 
- * main glib event loop
- **/
+ * main glib event loop.
+ */
 gboolean
 gnome_vfs_is_primary_thread (void)
 {
